==> adfurikun-1.0.1.tar.gz: example/lib/rectangle_sample.dart <==
import 'dart:io';

import 'package:adfurikun/rectangle.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class RectanglePage extends StatefulWidget {
  RectanglePage({Key? key}) : super(key: key);
  @override
  RectanglePageState createState() => RectanglePageState();
}

class RectanglePageState extends State<RectanglePage> with WidgetsBindingObserver {

  late AdfurikunRectangle rectangle;

  double width = 300;
  double height = 250;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Rectangle Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            Container(
                width: width,
                height: height,
                child: rectangle.adWidget()
            )
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_RECTANGLE_APPID;
    } else {
      appId = IOS_RECTANGLE_APPID;
    }
    rectangle = AdfurikunRectangle(appId, width, height);
    rectangle.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    WidgetsBinding.instance?.removeObserver(this);
    rectangle.destroy();
    rectangle.listener = null;
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (AppLifecycleState.resumed == state) {
      rectangle.resume();
    } else if (AppLifecycleState.paused == state) {
      rectangle.pause();
    }
  }

  void load() {
    rectangle.load();
  }

  void show() {
    rectangle.play();
  }

  void notifyCallback(AdfurikunRectangleCallback? callback, String? appId, String? adNetworkKey,
      String? title, String? description, int? errorCode) {
    if (AdfurikunRectangleCallback.onRectangleLoadFinish == callback) {
      Fluttertoast.showToast(msg: "読み込み成功");
    } else if (AdfurikunRectangleCallback.onRectangleLoadError == callback) {
      Fluttertoast.showToast(msg: "読み込み失敗");
    } else if (AdfurikunRectangleCallback.onRectangleViewPlayStart == callback) {
      Fluttertoast.showToast(msg: "再生開始");
    } else if (AdfurikunRectangleCallback.onRectangleViewPlayFinish == callback) {
      Fluttertoast.showToast(msg: "再生終了");
    } else if (AdfurikunRectangleCallback.onRectangleViewPlayFail == callback) {
      Fluttertoast.showToast(msg: "再生失敗");
    } else if (AdfurikunRectangleCallback.onRectangleViewClicked == callback) {
      Fluttertoast.showToast(msg: "広告クリック");
    }
  }
}

==> adfurikun-1.5.0.tar.gz: example/lib/rectangle_sample.dart <==
import 'dart:io';

import 'package:adfurikun/rectangle.dart';
import 'package:adfurikun_example/constants.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class RectanglePage extends StatefulWidget {
  RectanglePage({Key? key}) : super(key: key);
  @override
  RectanglePageState createState() => RectanglePageState();
}

class RectanglePageState extends State<RectanglePage> {

  late AdfurikunRectangle rectangle;

  double width = 300;
  double height = 250;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Rectangle Sample"),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          children: <Widget>[
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => load(),
                    child: Text("Load")
                )
            ),
            FractionallySizedBox(
                widthFactor: 0.9,
                child: ElevatedButton(
                    onPressed: () => show(),
                    child: Text("Show")
                )
            ),
            Container(
                width: width,
                height: height,
                child: rectangle.adWidget()
            )
          ],
        ),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    String appId = "";
    if (Platform.isAndroid) {
      appId = ANDROID_RECTANGLE_APPID;
    } else {
      appId = IOS_RECTANGLE_APPID;
    }
    rectangle = AdfurikunRectangle(appId, width, height);
    rectangle.listener = notifyCallback;
  }

  @override
  void dispose() {
    super.dispose();
    rectangle.destroy();
    rectangle.listener = null;
  }

  void load() {
    rectangle.load();
  }

  void show() {
    rectangle.play();
  }

  void notifyCallback(AdfurikunRectangleCallback? callback, String? appId, String? adNetworkKey,
      String? title, String? description, int? errorCode) {
    if (AdfurikunRectangleCallback.onRectangleLoadFinish == callback) {
      Fluttertoast.showToast(msg: "読み込み成功");
    } else if (AdfurikunRectangleCallback.onRectangleLoadError == callback) {
      Fluttertoast.showToast(msg: "読み込み失敗");
    } else if (AdfurikunRectangleCallback.onRectangleViewPlayStart == callback) {
      Fluttertoast.showToast(msg: "再生開始");
    } else if (AdfurikunRectangleCallback.onRectangleViewPlayFinish == callback) {
      Fluttertoast.showToast(msg: "再生終了");
    } else if (AdfurikunRectangleCallback.onRectangleViewPlayFail == callback) {
      Fluttertoast.showToast(msg: "再生失敗");
    } else if (AdfurikunRectangleCallback.onRectangleViewClicked == callback) {
      Fluttertoast.showToast(msg: "広告クリック");
    }
  }
}
